" Maintainer:   Jiri Tobisek <tobich@yahoo.com>
" Last Changed: 2001 Sep 30

let b:keymap = "czech"

loadkey
0	é
9	í
8	÷
7	ý
6	ŵ
5	ř
4	ī
3	ŷ
2	ě
1	+
`	;
)	0
(	9
*	8
&	7
^	6
%	5
$	4
#	3
@	2
!	1
]	)
}	(
[	ú
{	/
'	§
"	!
;	ů
:	"
/	-
?	_
>	:
<	?
|	'
~u	ů
~U	Ů
\\a	ä
\\e	ë
\\i	ï
\\o	ö
\\u	å
\\y	ÿ
\\A	Ä
\\E	Ë
\\I	ì
\\O	Ö
\\U	ö
\\Y	Ÿ
=a	÷
=e	é
=i	í
=o	ó
=u	ú
=y	ý
=A	Á
=E	É
=I	ë
=O	Ó
=U	ù
=Y	û
+c	ī
+d	Ĭ
+e	ě
+n	ň
+r	ř
+s	ŷ
+t	š
+z	ŵ
"y	z	If you prefere 'quertz' keyboard
"Y	Z	instead of 'querty',
"z	y	just uncomment these
"Z	Y	four last lines
