===============================================================================
=    W i t a j   w   t u t o r i a l u   V I M - a      -    Wersja  1.5.     =
===============================================================================

     Vim to potężny edytor, który posiada wiele poleceń, zbyt dużo by
     wyjaśnić je wszystkie w tym tutorialu. Ten przewodnik ma nauczyć
     Cię posługiwać się wystarczająco wieloma komendami byś mógł łatwo
     używać Vim-a jako edytora ogólnego przeznaczenia.

     Czas potrzebny na ukończenie tutoriala to 25 do 30 minut i zależy
     od tego jak wiele czasu spędzisz na eksperymentowaniu.  Polecenia
     wykonywane w czasie lekcji zmodyfikują tekst. Zrób wcześniej kopię
     tego pliku do ćwiczeń (jeśli zacząłeś komendą "vimtutor" to już
     pracujesz na kopii).

     Ważne jest, byś pamiętał, że przewodnik ten został zaprojektowany do
     nauki poprzez ćwiczenia. To oznacza, że musisz wykonywać polecenia
     by nauczyć się ich prawidłowo. Jeśli będziesz jedynie czytał tekst
     szybko zapomnisz wiele poleceń!

     Teraz upewnij się, że nie masz wciśniętego CapsLocka i wciskaj  j
     tak długo dopóki Lekcja 1.1. nie wypełni całkowicie ekranu.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		      Lekcja 1.1.: PORUSZANIE SIĘ KURSOREM

       ** By wykonać ruch kursorem, wciśnij h, j, k, l jak pokazano. **

	       ^
	       k		      Wskazówka:  h jest po lewej
	  < h	  l >				  l jest po prawej
	       j				  j wygląda jak strzałka w dół
	       v
  1. Poruszaj kursorem dopóki nie będziesz pewien, że pamiętasz polecenia.

  2. Trzymaj  j  tak długo aż będzie się powtarzał.
---> Teraz wiesz jak dojść do następnej lekcji.

  3. Używając strzałki w dół przejdź do następnej lekcji.

Uwaga: Jeśli nie jesteś pewien czegoś co wpisałeś, wciśnij <ESC> by wrócić do
       trybu Normal. Wtedy powtórz polecenie.

Uwaga: Klawisze kursora także powinny działać, ale używając  hjkl  będziesz
       w stanie poruszać się o wiele szybciej jak się tylko przyzwyczaisz.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		 Lekcja 1.2.: WCHODZENIE I WYCHODZENIE Z VIM-a

 !! UWAGA: Przed wykonaniem jakiegokolwiek polecenia przeczytaj całą lekcję.!!

  1. Wciśnij <ESC> (aby upewnić się, że jesteś w trybie Normal).
  2. Wpisz:			:q!<ENTER>.

---> To spowoduje wyjście z edytora BEZ zapamiętywania zmian jakie
     zdążyłeś zrobić. Jeśli chcesz zapamiętać zmiany i wyjść
     wpisz:			:wq<ENTER>

  3. Kiedy widzisz znak zachęty powłoki wpisz komendę, żeby wrócić
     do tutoriala.
     Powinienieś wpisać:	vimtutor<ENTER>
     Normalnie użyłbyś:		vim tutor<ENTER>

---> 'vim' oznacza edytor vim, 'tutor' jest plikem, który chciałbyś
     edytować.

  4. Jeśli chcesz zapamiętać polecenia, wykonaj kroki 1. do 3. aby
     wyjść i wrócić do edytora. Potem przenieś się do Lekcji 1.3.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 1.3.: EDYCJA TEKSTU - KASOWANIE


	** W trybie Normal wciśnij x aby usunąć znak pod kursorem. **

  1. Przenieś kursor do linii poniżej oznaczonej --->.

  2. By poprawić błędy, naprowadź kursor na znak do usunięcia.

  3. Wciśnij  x  aby usunąć niechciany znak.

  4. Powtarzaj kroki 2. do 4. dopóki zdanie nie jest poprawne.

---> Kkrowa prrzeskoczyła prrzez ksiiężycc.

  5. Teraz kiedy zdanie jest poprawione przejdź do Lekcji 1.4.

UWAGA: Ucz się przez ćwiczenie, nie wkuwanie.




~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	       Lekcja 1.4.: EDYCJA TEKSTU - INSERT (wprowadzanie)


	      ** W trybie Normal wciśnij  i  aby wstawić tekst. **

  1. Przenieś kursor do pierwszej linii poniżej oznaczonej --->.

  2. Aby poprawić pierwszy wiersz, ustaw kursor na pierwszym znaku PO tym
     gdzie tekst ma być wstawiony.

  3. Wciśnij  i  a następnie wpisz konieczne poprawki.

  4. Po poprawieniu błędu wciśnij <ESC> by wrócić do trybu Normal.
     Powtarzaj kroki 2. do 4. aby poprawić całe zdanie.

---> W tej brkje trochę .
---> W tej linii brakuje trochę tekstu.

  5. Kiedy czujesz się swobodnie wstawiając tekst przejdź do
     podsumowania poniżej.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 1. PODSUMOWANIE

  1. Poruszasz kursorem używając "strzałek" i klawiszy  hjkl .
       h (w lewo)	 j (w dół)	 k (do góry)		l (w prawo)

  2. By wejść do Vim-a (od znaku zachęty) wpisz:
			    vim NAZWA_PLIKU<ENTER>

  3. By wyjść z Vim-a wpisz:
			    <ESC> :q!<ENTER>  by usunąc wszystkie zmiany.
	     LUB:	    <ESC> :wq<ENTER>  by zmiany zachować.

  4. By usunąć znak pod kursorem w trybie Normal:  x

  5. By wstawić tekst przed kursorem w trybie Normal:
			    i	  type in text	      <ESC>

UWAGA: Wciśnięcie <ESC> przeniesie Cię z powrotem do trybu Normal
lub odwoła niechciane lub częściowo wprowadzone polecenia.

Teraz możemy kontynuować i przejść do Lekcji 2.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		  Lekcja 2.1.: POLECENIE DELETE (usuwanie)


	       ** Wpisz  dw  by usunąc tekst do końca wyrazu. **

  1. Wciśnij  <ESC>  by upewnić się, że jesteś w trybie Normal.

  2. Przenieś kursor do linii poniżej oznaczonej --->.

  3. Przesuń kursor na początek wyrazu, które chcesz usunąć.

  4. Wpisz   dw   by usunąc wyraz.

  UWAGA: Litery  dw  będą się pojawiać na dole ekranu w miarę
	 wpisywania.  Jeśli wpisałeś coś źle wciśnij <ESC> i zacznij od
	 początku.

---> Jest tu parę papier wyrazów, które kamień nie należą do nożyce tego zdania.

  5. Powtarzaj kroki 3. i 4. dopóki zdanie nie będzie poprawne, potem
  przejdź do Lekcji 2.2.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 2.2.: WIĘCEJ POLECEŃ USUWAJĄCYCH


	      ** Wpisz	d$  aby usunąć tekst do końca linii. **

  1. Wciśnij  <ESC>  aby się upewnić, że jesteś w trybie Normal.

  2. Przenieś kursor do linii poniżej oznaczonej --->.

  3. Przenieś kursor do końca poprawnego zdania (PO pierwszej  . ).

  4. Wpisz  d$  aby usunąć resztę linii.

---> Ktoś wpisał koniec tego zdania dwukrotnie. zdania dwukrotnie.


  5. Przejdź do Lekcji 2.3. by zrozumieć co się stało.





~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		     Lekcja 2.3.: O POLECENIACH I OBIEKTACH


  Format dla polecenia usuwającego  d  jest taki:

	    [liczba]  d  obiekt      LUB      d  [liczba]  obiekt

  Gdzie:
   liczba - ile razy polecenie ma być wykonane (opcjonalne, domyślna=1).
   d      - polecenie usuwające.
   obiekt - na czym polecenie będzie wykonywane (lista poniżej).

  Krótka lista obiektów:
    w - od kursora do końca wyrazu włączając spację.
    e - od kursora do końca wyrazu NIE włączając spacji.
    $ - od kursora do końca linii.

UWAGA: Dla ciekawskich, wybieranie obiektu w trybie Normal bez polecania
       polecenia przeniesie kursor tak jak opisano w liście obiektów.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		   Lekcja 2.4.: WYJĄTEK DO 'POLECENIE-OBIEKT'


		    ** Wpisz  dd   by usunąc całą linię. **

  Z powodu częstości usuwania całych linii, projektanci Vim-a zdecydowali, że
  będzie łatwiej wpisać dwa razy pod rząd d aby usunąć linię.

  1. Przenieś kursor do zdania poniżej.
  2. Wpisz  dd  aby usunąc wiersz.
  3. Teraz przenieś się do czwartego wiersza.
  4. Wpisz  2dd  (pamiętaj  liczba-polecenie-obiekt) aby usunąc dwia wiersze.

      1)  Róże są czerwone,
      2)  Błoto jest fajne,
      3)  Fiołki są niebieskie,
      4)  Mam samochód,
      5)  Zegar podaje czas,
      6)  Cukier jest słodki,
      7)  I ty też.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		      Lekcja 2.5.: POLECENIE UNDO (cofnij)


	  ** Wciśnij  u  aby cofnąć skutki ostatniego polecenia.
		 U zaś, by cofnąć skutki dla całej linii. **

  1. Przenieś kursor do zdania poniżej oznaczonego ---> i umieść go na
     pierwszym błędzie.
  2. Wpisz  x  aby usunąć pierwszy niechciany znak.
  3. Teraz wciśnij  u  aby cofnąć skutki ostatniego polecenia.
  4. Tym razem popraw wszystkie błędy w linii używając polecenia  x .
  5. Teraz wciśnij wielkie U aby przywrócić linię do oryginalnego stanu.
  6. Teraz wciśnij  u  kilka razy by cofnąć  U  i poprzednie polecenia.
  7. Teraz wpsz CTRL-R (trzymaj równocześnie wciśnięte klawisze CTRL i R)
     kilka razy, by cofnąć cofnięcia.

---> Poopraw blędyyy w teej liniii i zaamiień je prrzez coofnij.

  8. To są bardzo pożyteczne polecenia.

     Przejdź teraz do podsumowania Lekcji 2.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 2. PODSUMOWANIE

  1. By usunąć znaki od kursora do końca wyrazu wpisz:   dw

  2. By usunąć znaki od kursora do końca linii wpisz:    d$

  3. By usunąć całą linię:    dd

  4. Format polecenia w trybie Normal:

    [liczba]  polecenie  obiekt      LUB      polecenie  [liczba]  obiekt

  Gdzie:
   liczba    - ile razy polecenie ma być wykonane
   polecenie - to co trzeba zrobić (np.  d  dla usuwania)
   obiekt    - na czym polecenie będzie wykonywane, takie jak  w  (wyraz),
	       $  (do końca linii), etc.

  5. By cofnąć poprzednie polecenie, wpisz:	  u (małe u)
     By cofnąć wszystkie zmiany w linii wpisz:	  U (wielkie U)
     By cofnąć cofnięcia wpisz:			  CTRL-R

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			 Lekcja 3.1.: POLECENIE PUT (wstaw)


	  ** Wpisz  p  by wstawić ostatnie usunięcia po kursorze. **

  1. Przenieś kursor do pierwszej linii w zestawie poniżej.

  2. Wpisz  dd  aby usunąć linię i przechować ją w buforze Vim-a.

  3. Przenieś kursor do linii POWYŻEJ tej gdzie usunięta linia powinna
     się znajdować.

  4. W trybie Normal, wciśnij  p  by wstawić linię.

  5. Powtaj kroki 2. do 4. aż znajdą się w odpowiednim porządku.

     d) Jak dwa aniołki.
     b) Na dole fiołki,
     c) A my się kochamy,
     a) Na górze róże,


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 3.2.: POLECENIE REPLACE (zastąp)


       ** Wpisz  r  a następnie znak by zastąpić znak pod kursorem. **

  1. Przenieś kursor do pierwszej linii poniżej oznaczonej --->

  2. Ustaw kursor na pierwszym błędzie.

  3. Wpisz  r  a potem znak jaki powinien zastąpić błędny.

  4. Powtarzaj kroki 2. i 3. dopóki pierwsza linia nie będzie poprawna.

--->  Kjedy ten wiersz bił wstókiwany ktoś wciznął perę złych klawirzy!
--->  Kiedy ten wiersz był wstukiwany ktoś wcisnął parę złych klawiszy!

  5. Teraz czas na Lekcję 3.3.


UWAGA: Pamiętaj by uczyć się ćwicząc, a nie pamięciowo.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		     Lekcja 3.3.: POLECENIE CHANGE (zmień)

     ** By zmienić całe słowo lub jego część wpisz  cw  (change word). **

  1. Przenieś kursor do pierwszej linii poniżej oznaczonej --->.

  2. Umieść kursor na  u  w lunos.

  3. Wpisz  cw  i popraw wyraz (w tym wypadku wstaw 'inia').

  4. Wciśnij <ESC> i przejdź do następnego błędu (pierwszy znak, który ma
     ulec zmianie).

  5. Powtarzaj kroki 3. i 4. dopóki pierwsze zdanie nie będzie takie same
     jak drugie.

---> Ta lunos ma pire słów, które tżina zbnic użifajonc pcmazu zmień.
---> Ta linia ma parę słów, które trzeba zmienić używając polecenia zmień.

  Zauważ, że  cw  nie tylko zamienia wyraz, ale także zmienia tryb na
  Insert (wprowadzanie).

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		      Lekcja 3.4.: WIĘCEJ ZMIAN UŻYWAJĄC c


       ** Polecenie change używa takich samych obiektów jak delete. **

  1. Polecenie change działa tak samo jak delete. Format wygląda tak:

	    [liczba]  c  obiekt      LUB      c  [liczba]  obiekt

  2. Obiekty są także takie same, np.:  w  (wyraz),  $  (koniec linii), etc.

  3. Przenieś się do pierwszej linii poniżej oznaczonej --->

  4. Ustaw kursor na pierwszym błędzie.

  5. Wpisz  c$ , popraw koniec wiersza i wciśnij <ESC>.

---> Koniec tego wiersza musi być poprawiony aby wyglądal tak jak drugi.
---> Koniec tego wiersza musi być poprawiony używając polecenia  c$ .



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 3. PODSUMOWANIE


  1. Aby wstawić tekst, który został wcześniej usunięty wciśnij  p . To
     polecenie wstawia skasowany tekst PO kursorze (jeśli cała linia
     została usunięta, zostanie ona umieszczona w linii poniżej kursora).

  2. By zamienić znak pod kursorem wciśnij  r  a potem znak, który ma zastąpić
     oryginalny.

  3. Polecenie change pozwala Ci na zastąpienie wyszczególnionego obiektu
     od kursora do końca obiektu. Np. wpisz  cw  aby zamienić tekst od
     kursora do końca wyrazu,  c$  aby zmienić tekst do końca linii.

  4. Format do polecenia change (zmień):

	    [liczba]  c  obiekt      LUB      c  [liczba]  obiekt

     Teraz przejdź do następnej lekcji.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		   Lekcja 4.1.: LOKALIZACJA ORAZ STATUS PLIKU

       ** Naciśnij CTRL-G aby zobaczyć swoje położenie w pliku i status
	  pliku. Naciśnij SHIFT-G aby przejść do linii w pliku. **

  UWAGA: Przeczytaj całą lekcję zanim wykonasz jakieś polecenia!!!

  1. Przytrzymaj klawisz CTRL i wciśnij  g . Na dole strony pojawi się pasek
     statusu z nazwą pliku i numerem linii, w której jesteś. Zapamiętaj numer
     linii dla potrzeb kroku 3.

  2. Wciśnij SHIFT-G aby przejść na koniec pliku.

  3. Wpisz numer linii, w której byłeś a potem SHIFT-G.  To przeniesie Cię
     z powrotem do linii, w której byłeś kiedy wcisnąłeś CTRL-G (kiedy
     wpisujesz numery NIE pojawiają się one na ekranie).

  4. Jeśli czujesz się wystarczająco pewnie, wykonaj kroki 1-3.




~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			 Lekcja 4.2.: POLECENIE SZUKAJ


	     ** Wpisz  /  a następnie wyrażenie aby je znaleźć. **

  1. W trybie Normal wpisz  / . Zauważ, że znak ten, oraz kursor pojawią
     się na dole ekranu tak samo jak polecenie  : .

  2. Teraz wpisz  błond<ENTER> .  To jest słowo, którego chcesz szukać.

  3. By szukać tej samej frazy ponownie, po prostu wciśnij  n .
     Aby szukać tej frazy w przeciwnym, kierunku wciśnij SHIFT-N.

  4. Jeśli chcesz szukać frazy do tyłu, użyj polecenia  ?  zamiast  / .

---> Kiedy polecenie 'szukaj' osiągnie koniec pliku, przeszukiwanie
     zacznie się od początku pliku.

  'błond' to nie jest metoda by przeliterować błąd; 'błond' to błąd.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		Lekcja 4.3.: W POSZUKIWANIU PARUJĄCYCH NAWIASÓW


		** Wpisz  %  by znaleźć pasujący ),], lub } . **

  1. Umieść kursor na którymś z (, [, lub { w linii poniżej oznaczonej --->.

  2. Teraz wpisz znak  % .

  3. Kursor powinien się znaleźć na parującym nawiasie.

  4. Wciśnij  %  aby przenieść kursor z powrotem do parującego nawiasu.

---> To ( jest linia testowa z (, [, ] i {, } . ))

UWAGA: Ta funkcja jest bardzo użyteczna w debuggowaniu programu
       z niesparowanymi nawiasami!





~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		  Lekcja 4.4.: INNA METODA POPRAWIANIA BŁĘDÓW


	 ** Wpisz  :s/stary/nowy/g  aby zamienić 'stary' na 'nowy'. **

  1. Przenieś kursor do linii poniżej oznaczonej --->.

  2. Wpisz  :s/czaas/czas<ENTER> .  Zauważ, że to polecenie zmienia
     tylko pierwsze wystąpienie 'czaas' w linii.

  3. Teraz wpisz  :s/czaas/czas/g  oznacza zamianę (substytucję)
     globalnie w całej linii.  Zmienia wszystkie wystąpienia w linii.

---> Najlepszy czaas na zobaczenie najładniejszych kwiatów to czaas wiosny.

  4. Aby zmienić wszystkie wystąpienia łańcucha znaków pomiędzy dwoma liniami,
     wpisz: :#,#s/stare/nowe/g gdzie #,# są numerami dwóch linii.
     Wpisz  :%s/stare/nowe/g   by zmienić wszystkie wystąpienia w całym pliku.




~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 4. PODSUMOWANIE


  1. CTRL-G  pokaże Twoją pozycję w pliku i status pliku.  SHIFT-G przenosi
     Cię do końca pliku.  SHIFT-G poprzedzony liczbą przenosi Cię do linii
     o tym numerze.

  2. Wpisanie  /  a następnie łańcucha znaków szuka łańcucha DO PRZODU.
     Wpisanie  ?  a następnie łańcucha znaków szuka łańcucha DO TYŁU.
     Po wyszukiwaniu wciśnij  n  by znaleźć następne wystąpienie szukanej
     frazy tym samym kierunku lub Shift-N by szukać w kierunku przeciwnym.

  3. Wpisanie  %  gdy kursor znajduje się na (,),[,],{, lub } lokalizuje
     parujący znak.

  4. By zamienić pierwszy stary na nowy w linii wpisz      :s/stary/nowy
     By zamienić wszystkie stary na nowy w linii wpisz     :s/stary/nowy/g
     By zamienić frazy pomiędzy dwoma liniami # wpisz      :#,#s/stary/nowy/g
     By zamienić wszystkie wystąpienia w pliku wpisz       :%s/stary/nowy/g
     By Vim prosił Cię o potwierdzienie dodaj 'c'	   :%s/stary/nowy/gc


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		 Lekcja 5.1.: JAK WYKONAĆ POLECENIA ZEWNĘTRZNE


	** Wpisz  :!  a następnie zewnętrzne polecenie by je wykonać. **

  1. Wpisz znajome polecenie  :  by ustawić kursor na dole ekranu. To pozwala
     na wprowadzenie polecenia.

  2. Teraz wstaw  !  (wykrzyknik). To umożliwi Ci wykonanie dowolnego
     zewnętrznego polecenia powłoki.

  3. Jako przykład wpisz  ls  za  !  a następnie wciśnij <ENTER>. To polecenie
     pokaże spis plików w Twoim katalogu, tak jakbyś był przy znaku zachęty
     powłoki. Możesz też użyć  :!dir  jeśli  ls  nie działa.

---> Uwaga:  W ten sposób można wykonać wszystkie polecenia powłoki.
---> Uwaga:  Wszystkie polecenia  :  muszą być zakończone <ENTER>.





~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 5.2.: WIĘCEJ O ZAPISYWANIU PLIKÓW


	    ** By zachować zmiany w pliku wpisz :w NAZWA_PLIKU . **

  1. Wpisz  :!dir  lub  :!ls  by zobaczyć spis plików w katalogu.
     Już wiesz, że musisz wcisnąć <ENTER> po tym.

  2. Wybierz nazwę pliku jaka jeszcze nie istnieje, np. TEST.

  3. Teraz wpisz:   :w TEST   (gdzie TEST jest nazwą pliku jaką wybrałeś.)

  4. To polecenie zapamięta cały plik (Vim Tutor) pod nazwą TEST.
     By to sprawdzić wpisz  :!dir , żeby znowu zobaczyć listę plików.

---> Zauważ, że gdybyś teraz wyszedł z Vim-a, a następnie wszedł ponownie
     komendą  vim TEST , plik byłby dokładną kopią tutoriala kiedy go
     zapisywałeś.

  5. Teraz usuń plik wpisując:		   :!rm TEST


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		Lekcja 5.3.: SELEKTYWNE POLECENIE WRITE (zapisz)


	    ** By zachować część pliku wpisz  :#,# w NAZWA_PLIKU **

  1. Jeszcze raz wpisz  :!dir  lub  :!ls  by uzyskać listę plików
     w katalogu i wybierz odpowiednią nazwę taką jak TEST.

  2. Przenieś kursor na góre tej strony i wciśnij CTRL-G by uzyskać
     numer linii. ZAPAMIĘTAJ TĘ LICZBĘ!

  3. Teraz przenieś się na dół strony i wpisz  CTRL-G znowu.  ZAPAMIĘTAJ
     NUMER TAKŻE TEJ LINII!

  4. By zachować JEDYNIE część pliku wpisz  :#,# w TEST   gdzie  #,# to
     dwie liczby jakie zapamiętałeś (góra, dół ekranu), a TEST to nazwa
     Twojego pliku.

  5. Ponownie sprawdź czy ten plik tam jest ( :!dir ), ale NIE usuwaj go.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		   Lekcja 5.4.: WSTAWIANIE I ŁĄCZENIE PLIKÓW


	    ** By wstawić zawartość pliku wpisz   :r NAZWA_PLIKU **

  1. Wpisz  :!dir  by się upewnić, ze Twój plik TEST został poprawnie
     zapamiętany.

  2. Umieść kursor na górze strony.

UWAGA: Po wykonaniu kroku 3. ponownie zobaczysz Lekcję 5.3. Potem przejdź
       do DOŁU by zobaczyć ponownie tę lekcję.

  3. Teraz wczytaj plik TEST używając polecenia  :r TEST , gdzie TEST
     jest nazwą pliku.

UWAGA: Plik, który wczytujesz jest wstawiany tam gdzie był kursor.

  4. By sprawdzić czy plik został wczytany cofnij kursor i zobacz, że
     teraz są dwie kopie Lekcji 5.3., oryginał i kopia z pliku.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 5. PODSUMOWANIE


  1.  :!polecenie wykonuje polecenie zewnętrzne.

      Użytecznymi przykładami są:

	  :!dir  -  pokazuje spis plików w katalogu.

	  :!rm NAZWA_PLIKU  -  usuwa plik NAZWA_PLIKU.

  2.  :w NAZWA_PLIKU  zapisuje obecny plik Vim-a na dysk z nazwą NAZWA_PLIKU.

  3.  :#,#w NAZWA_PLIKU  zapisuje linie od # do # w pliku NAZWA_PLIKU.

  4.  :r NAZWA_PLIKU  wczytuje z dysku plik NAZWA_PLIKU i wstawia go do
      bieżącego pliku po kursorze.





~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		      Lekcja 6.1.: POLECENIE OPEN (otwórz)


      ** Wpisz  o  by otworzyć linię poniżej kursora i przenieść się do
	 trybu Insert (wprowadzanie). **

  1. Przenieś kursor do linii poniżej oznaczonej --->.

  2. Wpisz  o  (małe) by otworzyć linię PONIŻEJ kursora i przenieść się
     do trybu Insert (wprowadzanie).

  3. Teraz przepisz linię oznaczoną ---> i wciśnij <ESC> by wyjść
     z trybu Insert (wprowadzanie).

---> Po wciśnięciu  o  kursor znajdzie się w otwartej linii w trybie
     Insert (wprowadzanie).

  4. By otworzyć linię POWYŻEJ kursora wciśnij wielkie  O  zamiast małego
     o . Wypróbuj to na linii poniżej.

 Otwórz linię powyżej wciskając SHIFT-O gdy kursor będzie na tej linii.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		     Lekcja 6.2.: POLECENIE APPEND (dodaj)


		  ** Wpisz  a  by dodać tekst ZA kursorem. **

  1. Przenieś kursor do końca pierwszej linii poniżej oznaczonej --->
     Zrób to wciskając  $  w trybie Normal.

  2. Wpisz  a  (małe) aby dodać tekst ZA znakiem pod kursorem.
     Wielkie A dodaje tekst na końcu linii.

Uwaga: To oszczędza wpisania: ostatni znak ( $ ),  i , tekst do dodania,
       <ESC>, strzałka w prawo i ostatecznie  x , tylko po to by dodać
       tekst na końcu linii.

  3. Teraz dokończ pierwszą linię. Zauważ także, że  append  (dodaj)
     działa tak samo jak tryb Insert (wprowadzanie) z wyjątkiem tego gdzie
     tekst jest wstawiany.

---> Ta linia pozwoli Ci ćwiczyć
---> Ta linia pozwoli Ci ćwiczyć dodawanie tekstu do końca linii.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		   Lekcja 6.3.: INNA WERSJA REPLACE (zamiana)


	   ** Wpisz wielkie  R  by zamienić więcej niż jeden znak. **

  1. Przenieś kursor do pierwszej linii poniżej oznaczonej --->.

  2. Umieść kursor na początku pierwszego wyrazu, który rózni się od
     drugiej linii oznaczonej ---> (wyraz 'ostatni').

  3. Teraz wpisz  R  i zamień resztę tekstu w pierwszej linii przez
     nadpisanie nad starym tekstem tak aby pierwsza linia brzmiała tak samo
     jak druga.

---> To make the first line the same as the last on this page use the keys.
---> To make the first line the same as the second, type R and the new text.

  4. Zauważ, że kiedy wciśniesz <ESC> aby wyjść niezmieniony tekst
     pozostaje.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			 Lekcja 6.4.: USTAWIANIE OPCJI


** Ustawianie opcji tak by szukaj lub substytucja ignorowały wielkość liter **

  1. Szukaj 'ignore' wpisując (w trybie Normal):
     /ignore
     Powtórz szukanie kilka razy naciskając klawisz  n .

  2. Ustaw opcję 'ic' (Ignore case -- ignoruj wielkość liter) poprzez
     wpisanie:		:set ic

  3. Teraz szukaj 'ignore' ponownie wciskując: n
     Powtórz szukanie kilka razy naciskając klawisz  n .

  4. Ustaw opcje 'hlsearch' i 'incsearch':
     :set hls is

  5. Teraz wprowadź polecenie szukaj ponownie i zobacz co się zdarzy:
     /ignore


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 6. PODSUMOWANIE


  1. Wpisanie  o  otwiera linię PONIŻEJ kursora i umieszcza kursor
     w otwartej linii w trybie Insert (wprowadzanie).
     Wpisanie wielkiego  O  otwiera linię POWYŻEJ linii, w której
     znajduje się kursor.

  2. Wpisz  a  by wstawić tekst ZA znakiem na, którym jest kursor.
     Wpisanie wielkiego  A  automatycznie dodaje tekst na końcu linii.

  3. Wpisanie wielkiego  R  wprowadza w tryb Replace (zamiana) dopóki
     nie zostanie wciśnięty <ESC>.

  4. Wpisanie ":set xxx" ustawia opcję "xxx".







~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		       LEKCJA 7. POLECENIA POMOCY ON-LINE


		      ** Użycie systemu pomocy on-line **

  Vim posiada bardzo dobry system pomocy on-line. By zacząć spróbuj jednej
  z trzech możliwości:

	- wciśnij klawisz <HELP> (jeśli takowy posiadasz)
	- wciśnij klawisz <F1> (jeśli takowy posiadasz)
	- wpisz   :help<ENTER>

  Wpisz   :q<ENTER>   by zamknąc okno pomocy.

  Możesz też znaleźć pomoc na każdy temat podając argument polecenia ":help".
  Spróbuj tych (nie zapomnij wcisnąć <ENTER>):

  :help w
  :help c_<T
  :help insert-index
  :help user-manual

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		     LEKCJA 8. TWORZENIE SKRYPTU STARTOWEGO

			** Włączanie możliwości Vim-a **

  Vim ma o wiele więcej możliwości niż Vi, ale większość z nich jest domyślnie
  wyłączona. Jeśli chcesz włączyć te możliwości na starcie musisz utworzyć
  plik "vimrc".

  1. Początek edycji pliku "vimrc" zależy od Twojego systemu:
     :edit ~/.vimrc	     dla Unixa
     :edit $VIM/_vimrc       dla MS-Windows

  2. Teraz wczytaj przykładowy plik "vimrc":
     :read $VIMRUNTIME/vimrc_example.vim

  3. Zapisz plik:
     :write

  Następnym razem gdy zaczniesz pracę w Vimie będzie on używać podświetlania
  składni. Możesz dodać wszystkie swoje ulubione ustawienia do tego pliku
  "vimrc".

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  Tutaj się kończy tutorial Vim-a. Został on pomyślany tak aby dać krótki
  przegląd jego możliwości, wystarczający byś mógł go używać. Jest on
  daleki od kompletności ponieważ Vim ma o wiele, wiele więcej poleceń.

  Dla dalszej nauki rekomendujemy książkę:
	Vim - Vi Improved - autor Steve Oualline
	Wydawca: New Riders
  Pierwsza ksiązka całkowicie poświęcona Vim-owi. Użyteczna zwłaszcza dla
  początkujących. Zawiera wiele przykładów i ilustracji.
  Zobacz http://iccf-holland.org./click5.html

  Ta książka jest starsza i bardziej o Vi niż o Vim-ie, ale także warta
  polecenia:
	Learning the Vi Editor - autor Linda Lamb
	Wydawca: O'Reilly & Associates Inc.
  To dobra książka by dowiedzieć się niemal wszystkiego co chciałbyś zrobić
  z Vi. Szósta edycja zawiera też informacje o Vim-ie.

  Po polsku wydano:
	Edytor vi. Leksykon kieszonkowy - autor Arnold Robbins
	Wydawca: Helion 2001 (O'Reilly).
	ISBN: 83-7197-472-8
	http://helion.pl/ksiazki/vilek.htm
  Jest to książeczka zawierająca spis poleceń vi i jego najważniejszych
  klonów (między innymi Vim-a).

	Edytor vi - autorzy Linda Lamb i Arnold Robbins
	Wydawca: Helion 2001 (O'Reilly) - wg 6 ang. wydania
	ISBN: 83-7197-539-2
	http://helion.pl/ksiazki/viedyt.htm
  Rozszerzona wersja Learning the Vi Editor w polskim tłumaczeniu.

  Ten tutorial został napisany przez Michaela C. Pierce'a i Roberta K. Ware'a,
  Colorado School of Mines korzystając z pomocy Charlesa Smitha,
  Colorado State University.
  E-mail: bware@mines.colorado.edu.

  Zmodyfikowane dla Vim-a przez Brama Moolenaara.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  Przetłumaczone przez Mikołaja Machowskiego,
  Sierpień 2001,
  rev. Marzec 2002
  Wszelkie uwagi proszę kierować na: mikmach@wp.pl

