" Vim filetype plugin
" Language:	MetaPost
" Maintainer:	Dorai Sitaram <ds26@gte.com>
" URL:		http://www.ccs.neu.edu/~dorai/vimplugins/vimplugins.html
" Last Change:	May 27, 2003

runtime! ftplugin/mf.vim ftplugin/mf_*.vim ftplugin/mf/*.vim
