" Vim filetype plugin file
" Langugage:	    Automake
" Maintainer:	    Nikolai Weibull <source@pcppopper.org>
" URL:		    http://www.pcppopper.org/vim/ftplugin/pcp/automake/
" Latest Revision:  2004-05-22
" arch-tag:	    3a78b0cd-27b2-410a-8e7b-51a1717c2a5b

" Same as makefile filetype plugin for now.
runtime! ftplugin/make.vim ftplugin/make_*.vim ftplugin/make/*.vim

" vim: set sts=2 sw=2:
