" Vim Keymap file for Persian Standard Keyboard Layout
" Maintainers: Behnam Esfahbod <behnam@bamdad.org>,
"	       Amir Hedayaty <amir@bamdad.org>
" Last Change: 2004 May 16

" All characters are given literally, conversion to another encoding (e.g.,
" UTF-8) should work.
scriptencoding utf-8

" Use this short name in the status line.
let b:keymap_name = "per"

loadkeymap
`	‍
1	۱
2	۲
3	۳
4	۴
5	۵
6	۶
7	۷
8	۸
9	۹
0	۰
-	-
=	=

q	ض
w	ص
e	ث
r	ق
t	ف
y	غ
u	ع
i	ه
o	خ
p	ح
[	ج
]	چ

a	ش
s	س
d	ی
f	ب
g	ل
h	ا
j	ت
k	ن
l	م
;	ک
'	گ

z	ظ
x	ط
c	ز
v	ر
b	ذ
n	د
m	پ
,	و
.	.
/	/
\	\

~	÷
!	!
@	٬
#	٫
$	﷼
%	٪
^	×
&	،
*	*
(	)
)	(
_	ـ
+	+

Q	ْ
W	ٌ
E	ٍ
R	ً
T	ُ
Y	ِ
U	َ
I	ّ
O	]
P	[
{	}
}	{

A	ؤ
S	ئ
D	ي
F	إ
G	أ
H	آ
J	ة
K	»
L	«
:	:
\"	؛

Z	ك
X	ٓ
C	ژ
V	ٰ
B	‌
N	ٔ
M	ء
<	>
>	<
?	؟
|	|

